@@ -1,4 +1,6 @@
-g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredtz = c()) {
+g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredtz = c(), configtz = c()) {
+
+  if (length(configtz) == 0) configtz = desiredtz
   # Credits: The code in this function was contributed by Dr. Evgeny Mirkes (Leicester University, UK)
   #========================================================================
   # fileName is namer of cwa file to read
@@ -54,7 +56,7 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
       # Form string representation of date and convert it to number
       year = as.numeric(as.POSIXct(
         paste0(year, "-", month, "-", day, " ", hours, ":", mins, ":", secs),
-      tz=desiredtz))
+      tz=configtz))
     }
     else{
       secs = bitwAnd(coded, 0x3fL)
@@ -107,7 +109,6 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
       if (is.null(datas)){
         stop("Error in the first data block reading")
       }
-
       if (frequency != datas$frequency){
         warning("Inconsistent value of measurement frequency: there is ",
                 frequency, " in header and ", datas$frequency, " in the first data block ")
@@ -115,10 +116,12 @@ g.cwaread = function(fileName, start = 0, end = 0, progressBar = FALSE, desiredt
     } else {
       return(invisible(NULL))
     }
+    # start = as.POSIXct(datas$start, origin = "1970-01-01", tz=configtz)
+    start = as.POSIXct(datas$start, origin = "1970-01-01", tz=desiredtz)
     return(invisible(
       list(
         uniqueSerialCode = uniqueSerialCode, frequency = frequency,
-        start = as.POSIXct(datas$start, origin = "1970-01-01", tz=desiredtz),
+        start = start,
         device = "Axivity", firmwareVersion = version, blocks = numDBlocks
       )
     ))
